Welcome to django-ordinary-news’s documentation! — django-ordinary-news v0.0.1 documentation

### Navigation

- index
- next |
- django-ordinary-news v0.0.1 documentation »

# Welcome to django-ordinary-news’s documentation!

Contents:

- Installation

- Usage
  - Templates

# Django ordinary news

Application provides news functionality for your site.

It contains only one model

class `news.models.` `NewsItem`
  `title`
    News title
  `slug`
    Slug. If None provided, id attribute will be inserted while saving
  `date`
    Publication date.
  `short`
    Short summary of news item.
  `text`
    Full text. TinyMCE Field used.

  ..attribute:: published

  > Display this item on site or not

### Navigation

- index
- next |
- django-ordinary-news v0.0.1 documentation »